# -*- coding: utf-8 -*-
from collective.MockMailHost.testing import COLLECTIVE_MOCKMAILHOST_FUNCTIONAL_TESTING
from collective.MockMailHost.testing import optionflags
from plone.testing import layered

import doctest
import unittest


doctests = (
    'SendEmail.txt',
)

def test_suite():
    suite = unittest.TestSuite()
    tests = [
        layered(
            doctest.DocFileSuite(
                'tests/{0}'.format(test_file),
                package='collective.MockMailHost',
                optionflags=optionflags,
            ),
            layer=COLLECTIVE_MOCKMAILHOST_FUNCTIONAL_TESTING,
        )
        for test_file in doctests
    ]
    suite.addTests(tests)
    return suite



from Products.CMFCore import utils as CMFCoreUtils

def initialize(context):
    from . import MockMailHost
    tools = (MockMailHost.MockMailHost, )
    CMFCoreUtils.ToolInit(MockMailHost.META_TYPE,
                          tools=tools,
                          icon='MailHost_icon.gif').initialize(context)



# -*- coding: utf-8 -*-
from plone.app.testing import applyProfile
from plone.app.testing import PloneSandboxLayer
from plone.app.testing.layers import FunctionalTesting
from plone.app.testing.layers import IntegrationTesting
import doctest


class CollectiveMockMailHostLayer(PloneSandboxLayer):

    def setUpZope(self, app, configurationContext):
        import collective.MockMailHost
        self.loadZCML(package=collective.MockMailHost)

    def setUpPloneSite(self, portal):
        applyProfile(portal, 'collective.MockMailHost:default')

COLLECTIVE_MOCKMAILHOST_FIXTURE = CollectiveMockMailHostLayer()

COLLECTIVE_MOCKMAILHOST_INTEGRATION_TESTING = IntegrationTesting(
    bases=(COLLECTIVE_MOCKMAILHOST_FIXTURE, ),
    name='CollectiveMockMailHostLayer:Integration'
)
COLLECTIVE_MOCKMAILHOST_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(COLLECTIVE_MOCKMAILHOST_FIXTURE, ),
    name='CollectiveMockMailHostLayer:Functional'
)

optionflags = (
    doctest.REPORT_ONLY_FIRST_FAILURE
    | doctest.ELLIPSIS
    | doctest.NORMALIZE_WHITESPACE
)



# -*- coding: utf-8 -*-
from Products.MailHost import MailHost

import email.message
import six


META_TYPE = 'MockMailHost'


class MockMailHost(MailHost.MailHost):

    meta_type = META_TYPE

    def __init__(self, id=''):
        super(MockMailHost, self).__init__(id)
        self.reset()

    def reset(self):
        self.messages = []
        self.msg_types = []
        self._p_changed = True

    def _send(self, mfrom, mto, messageText, debug=False):
        if isinstance(messageText, email.message.Message):
            if six.PY2:
                message = messageText.as_string()
            else:
                message = email.message_from_string(messageText)
        else:
            message = messageText
        self.messages.append(message)
        self._p_changed = True

    def send(self,
             messageText,
             mto=None,
             mfrom=None,
             subject=None,
             encode=None,
             immediate=False,
             charset=None,
             msg_type=None,
             ):

        # messageText may be an MIMEText object, or something else.
        # We onyl want to clean it up if it is a string.
        if isinstance(messageText, (str, six.text_type)):
            messageText = '\n'.join([x.strip() for x in messageText.split('\n')])

        self.msg_types.append(msg_type)
        super(MockMailHost, self).send(messageText, mto, mfrom,
                                       subject, encode, immediate, charset,
                                       msg_type)

    def pop(self, idx=-1):
        result = self.messages.pop(idx)
        self._p_changed = True
        return result

    def __len__(self):
        return len(self.messages)



from Products.Five.browser import BrowserView


class MyView(BrowserView):
    """ view for mockmailhost """
    def __call__(self):
        context = self.context
        if context.messages:
            return context.pop(0)
        return 'NO MESSAGE'



from Products.CMFCore.utils import getToolByName
from Products.MailHost.interfaces import IMailHost


def setupVarious(context):
    if not context.readDataFile('mockmailhost_various.txt'):
        return
    site = context.getSite()
    replace_mailhost(site)


def replace_mailhost(self):
    portal = getToolByName(self, 'portal_url').getPortalObject()
    portal._delObject('MailHost')
    portal._setObject('MailHost', portal.MockMailHost)

    sm = self.getSiteManager()
    sm.registerUtility(portal.MailHost, provided=IMailHost)



from setuptools import setup, find_packages
import os

version = '2.0.0'

setup(
    name='collective.MockMailHost',
    version=version,
    description="Used for integration testing with Plone",
    long_description="\n".join([
        open("README.rst").read(),
        open(os.path.join("collective", "MockMailHost", "tests",
                          "SendEmail.txt")).read(),
        open("CHANGES.rst").read(),
    ]),
    # Get more strings from https://pypi.org/classifiers
    classifiers=[
        "Framework :: Plone",
        "License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    keywords='mock mailhost tests',
    author='Suresh V.',
    author_email='suresh@grafware.com',
    url='https://github.com/collective/collective.mockmailhost',
    license='GPL',
    packages=find_packages(exclude=['ez_setup']),
    namespace_packages=['collective'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
      'setuptools',
      'Products.GenericSetup',
      'Products.MailHost',
      'Products.CMFCore',
      # -*- Extra requirements: -*-
    ],
    extras_require={
      'test': [
          'plone.app.testing',
          'plone.testing',
          'zope.component',
      ],
    },
    entry_points="""
    # -*- Entry points: -*-

    [z3c.autoinclude.plugin]
    target = plone
    """,
)
